@@ -1,6 +1,6 @@
-/* GNU Chess 5.90 - components.cc - Pipes shared across modules
+/* GNU Chess 6 - components.cc - Pipes shared across modules
 
-   Copyright (c) 2001-2011 Free Software Foundation, Inc.
+   Copyright (c) 2001-2012 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs 
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -65,6 +65,7 @@ void *adapter_func(void *arg)
   InitEngine();
   /* Start adapter main loop */
   adapter::main_adapter( 0, 0 );
+  return 0;
 }
 
 /*
@@ -100,6 +101,7 @@ void *engine_func(void *arg)
 {
   /* Start engine main loop */
   engine::main_engine( 0, 0 );
+  return 0;
 }
 
 /*
